@@ -775,31 +775,6 @@ class Fs_sip_module_class extends Fs_module_class
                     $xml_writer->writeAttribute("name", $domain->name());
                     $xml_writer->writeAttribute("alias", "false");
                     $xml_writer->writeAttribute("parse", "false");
-                    $domain_data = $domain->get_data_values(false);
-                    // Filter out registration if disable
-                    if (isset($domain_data['forward-registration']) && 'true' != $domain_data['forward-registration']) {
-                        // unset all forward registration info to avoid invalid config
-                        unset($domain_data['registrar-server']);
-                        unset($domain_data['registrar-port']);
-                        unset($domain_data['registrar-profile']);
-                        unset($domain_data['sip-force-expires']);
-                        unset($domain_data['register-transport']);
-                    } else {
-                        // Forward to Profile ?
-                        if (!isset($domain_data['registrar-profile']) || 'none' == $domain_data['registrar-profile']) {
-                            unset($domain_data['registrar-profile']);
-                        }
-                    }
-                    // In any cases remove forward registration flag
-                    unset($domain_data['forward-registration']);
-                    foreach ($domain_data as $k => $v) {
-                        if($v){
-                            $xml_writer->startElement("param");
-                            $xml_writer->writeAttribute("name", $k);
-                            $xml_writer->writeAttribute("value", $v);
-                            $xml_writer->EndElement(); //end param tag
-                        }
-                    }
                     $xml_writer->EndElement(); //end domain tag
                     
                 } else {
