@@ -92,7 +92,8 @@ class Nsc_domain_profiles extends Safe_CI_Controller
             'Domain Name',
             'Forward',
             'Registrar Server',
-            'Registrar Port'
+            'Registrar Port',
+            'Force Expires',
         ));
         $table->set_controller_url($this->router->fetch_class());
         foreach ($this->_domain_profiles as $profile) {
@@ -103,6 +104,7 @@ class Nsc_domain_profiles extends Safe_CI_Controller
                     $prof_data['forward-registration'],
                     ($profile->is_forward_enabled()) ? $prof_data['registrar-server'] : 'N/A',
                     ($profile->is_forward_enabled()) ? $prof_data['registrar-port'] : 'N/A',
+                    $prof_data['sip-force-expires'],
                 ) , $profile->name() , 'Modify|Delete:confirm', '');
             }
         }
@@ -234,6 +236,7 @@ class Nsc_domain_profiles extends Safe_CI_Controller
         if (strtolower($config_values["forward-registration"]) == 'disable') {
             $table_line = array(
                 'Forward Registration / Authentication' => $config_values["forward-registration"],
+                'SIP Force Expires' => $config_values["sip-force-expires"],
                 '' => $table->create_button(true, 'Edit', $button_css_class = '', $table->primary_key)
             );
         } else {
@@ -241,6 +244,7 @@ class Nsc_domain_profiles extends Safe_CI_Controller
                 'Forward Registration / Authentication' => $config_values["forward-registration"],
                 'Registrar Server' => $config_values["registrar-server"],
                 'Registrar Server Port' => $config_values["registrar-port"],
+                'SIP Force Expires' => $config_values["sip-force-expires"],
                 '' => $table->create_button(true, 'Edit', $button_css_class = '', $table->primary_key) /*.
                  $table->create_button(true, 'Cancel', $button_css_class='', '')*/
             );
@@ -402,7 +406,8 @@ class Nsc_domain_profiles extends Safe_CI_Controller
         $table->set_headings(array(
             'User ID',
             'Caller ID Name',
-            'Caller ID Number'
+            'Caller ID Number',
+            'SIP Force Expires',
         ));
         $table->set_controller_url($this->router->fetch_class());
         $table->set_url_suffix('user/' . $domain->name());
@@ -415,6 +420,7 @@ class Nsc_domain_profiles extends Safe_CI_Controller
                     $profile->name() ,
                     $prof_data['effective_caller_id_name'],
                     $prof_data['effective_caller_id_number'],
+                    $prof_data['sip_force_expires'],
                 ) , $profile->id() , 'Edit|Delete:confirm', '', true);
             }
         }
