@@ -96,7 +96,21 @@ class Ntg_media_server_interfaces extends Safe_CI_Controller
             );
             $mode_data['table'] = $table->generate_vertical_line_table('1', '2', $table_line);
             unset($table);
-            foreach ($this->_ethernet_if as $if) {
+            foreach (array_merge($this->_ethernet_if, $this->_transcoding_if) as $if) {
+                if(!$if->modules()){
+                    continue;
+                }
+                // Check modules up to date ?
+                if(!$if->check_modules_version()){
+                    $data['notif_error'] = array('notif_error' =>
+                        safe_form_with_submit_button_confirm(
+                            'Media Server Modules Version Out Of Date.',
+                            '/SAFe/ntg_media_server_interfaces/update_confirm', 'Update',
+                            '')
+                    );
+                    continue;
+                }
+
                 if ($if->ip_address() != "") {
                     $table = new Safe_table_class();
                     // Prepare heading
@@ -140,53 +154,13 @@ class Ntg_media_server_interfaces extends Safe_CI_Controller
                     unset($create_table);
                 }
             }
-            foreach ($this->_transcoding_if as $if) {
-                $table = new Safe_table_class();
-                // Prepare heading
-                $table->heading = array(
-                    '',
-                    'MAC',
-                    'Version',
-                    'IP address',
-                    'UDP Ports'
-                );
-                $i = 0;
-                // Prepare rows
-                $table->data = array();
-                $table->line_button = array();
-                foreach ($if->modules() as $mod) {
-                    if ($mod->mac() != "") {
-                        $table->data[] = array(
-                            (true == $mod->enable()) ? WEBCONFIG_ICON_OK : WEBCONFIG_ICON_XMARK,
-                            strtoupper($mod->mac()) ,
-                            $mod->version() ,
-                            $mod->ip_address() ,
-                            $mod->udp_begin() . ' - ' . $mod->udp_end() ,
-                        );
-                        array_push($table->primary_key, $mod->mac());
-                        array_push($table->line_button, array(
-                            array(
-                                'url' => '/SAFe/ntg_media_server_interfaces/edit/' . $if->name() ,
-                                'name' => 'Edit',
-                                'label' => ''
-                            )
-                        ));
-                        $i++;
-                        $create_table = true;
-                    } else $create_table = false;
-                }
-                // Generate table HTML code
-                if ($create_table) $data['tables'][] = array(
-                    'table_title' => 'Media interface ' . $if->name() ,
-                    'table' => $table->generate()
-                );
-            }
         }
         unset($table);
         //load js and css
         $this->load->view("safe_confirm_dialog", $data);
         // Display
         if ($mode_data) $this->load->view("safe_table", $mode_data);
+        $this->load->view("safe_notifications", $data);
         $this->load->view("safe_multitable", $data);
         $this->load->view("safe_footer", $data);
     }
@@ -206,6 +180,26 @@ class Ntg_media_server_interfaces extends Safe_CI_Controller
         $data['action_url'] = $this->router->fetch_class(). '/' . 'modify_action';
         echo json_encode($data);
     }
+    public function update_confirm()
+    {
+        // Set the basic data
+        $data['page_title'] = 'Update Media Interfaces';
+        if(Safe_service_class::STATUS_RUNNING == $this->_the_app->status()){
+            $data['message'] = 'Cannot Update Media Interfaces while '.$this->_the_app->description().' is Running.';
+            $data['message_type'] = 'alert';
+            //for ajax json data return
+            $data['result'] = false;
+            $data['action_url'] = $this->router->fetch_class();
+        }else{
+            $data['message'] = 'Interfaces Update process will delete current configuration!';
+            $data['message_type'] = 'alert';
+            //for ajax json data return
+            $data['result'] = true;
+            $data['action_url'] = $this->router->fetch_class(). '/' . 'update_action';
+        }
+        echo json_encode($data);
+    }
+
     /**
      *  Modify Media Interfaces action
      *
@@ -217,6 +211,70 @@ class Ntg_media_server_interfaces extends Safe_CI_Controller
         $data['redirect_url'] =  $this->router->fetch_class(). '/' . 'scan';
         echo json_encode($data);
     }
+    public function update_action()
+    {
+        //for ajax json data return
+        $data['result'] = true;
+        $data['redirect_url'] =  $this->router->fetch_class(). '/' . 'update';
+        echo json_encode($data);
+    }
+
+    public function update()
+    {
+        // Set the basic data
+        $data['page_title'] = 'Media Server Interfaces detection';
+        $data['page_summary'] = 'This page allows Updating Media Server Interfaces.';
+        $data['page_large_icon'] = '/images/icons/32x32/icon-network.png';
+        $data['page_small_icon'] = '/images/icons/16x16/icon-network.png';
+        // Display wait
+        $data['wait_message'] = '</br><b>Updating Media Server Interfaces...</b><br/>This may take several minutes</br>&nbsp;';
+        $data['timeout_sec'] = 600;
+        $this->load->view("safe_header", $data);
+        $this->load->view("safe_confirm_dialog", $data);
+        $this->load->view("safe_wait", $data);
+        safe_flush_ouput();
+
+        // Proceed to update
+        $adapters = $this->_hardware->adapters();
+
+        $full_output = array();
+        $success = true;
+
+        foreach($adapters as $adapter){
+            $output = array();
+            if(!$adapter->api_upgrade_module(null, null, $output)){
+                $success = false;
+            }
+            $full_output = array_merge($full_output, $output);
+        }
+        if($success){
+            $data['notif_warn'][] = 'Media Server Interfaces Update Completed Successfully.';
+            $data['notif_warn'][] = safe_form_with_submit_button(
+                'Please ', 
+                '/SAFe/ntg_media_server_interfaces/scan', 'Click Here to re-scan.', '');
+        }else{
+            $data['notif_error'][] = 'Media Server Interfaces Update Failed.';
+            $table = new Safe_table_class();
+            $table->apply_data_formatter = false;
+            $data['table_title'] = 'Media Server Interface Update';
+            $table->data = $full_output;
+            $table->footer_button = array(
+                    array(
+                            'url' => '/SAFe/' . $this->router->fetch_class(),
+                            'name' => 'Back'
+                    )   
+            );  
+            
+            $data['table'] = $table->generate();
+        }
+
+        $this->load->view("safe_notifications", $data);
+        if($data['table']){
+            $this->load->view("safe_table", $data);
+        }
+        $this->load->view("safe_footer", $data);
+    }
+
     public function scan()
     {
         // verify if logged
@@ -235,6 +293,7 @@ class Ntg_media_server_interfaces extends Safe_CI_Controller
         $post = $this->input->post();
         if (isset($post['cancel'])) {
             safe_redirect('/SAFe/ntg_media_server_interfaces');
+            exit();
         }
         // Is this a scan request ?
         elseif (isset($post['scan'])) {
@@ -244,6 +303,7 @@ class Ntg_media_server_interfaces extends Safe_CI_Controller
                 $param->set_data_values($post);
                 $param->serialize();
                 safe_redirect('/SAFe/ntg_media_server_interfaces');
+                exit();
             }
             //If the user selected to enable media interfaces or there is a transcoding adapter, continue
             elseif ($post['enable_media_interface'] || !empty($this->_transcoding_if)) {
@@ -254,6 +314,12 @@ class Ntg_media_server_interfaces extends Safe_CI_Controller
                 $config = $param->get_data();
                 $this->load->library("safe_form_class", $config);
                 if ($this->safe_form_class->run_validation($validation_errors)) {
+                    // Process to adapter detection
+                    $data['wait_message'] = '</br><b>Detecting Media Server Interfaces...</b></br>&nbsp;';
+                    $this->load->view("safe_confirm_dialog", $data);
+                    $this->load->view("safe_wait", $data);
+                    safe_flush_ouput();
+
                     $param->serialize();
                     //Remove all old information from the db
                     foreach ($this->_transcoding_if as $if) {
@@ -264,11 +330,6 @@ class Ntg_media_server_interfaces extends Safe_CI_Controller
                         $if->delete_media_info();
                     }
                     unset($if);
-                    // Process to adapter detection
-                    $data['wait_message'] = '</br><b>Detecting Media Server Interfaces...</b></br>&nbsp;';
-                    $this->load->view("safe_confirm_dialog", $data);
-                    $this->load->view("safe_wait", $data);
-                    safe_flush_ouput();
                     unset($post['scan']);
                     $post_copy = $post;
                     // Check if external ip defined
