@@ -247,10 +247,7 @@ class Safe_application_class extends Safe_service_class
                         'pattern' =>  $cfg_manager->directory('base') . '/upload/license.tgz',
                         'global_capabilities_no_data' => array(
                                 'upload'
-                        ) ,
-                        'capabilities' => array(
-                                'view'
-                                )
+                        )
                 );
         }
         if (isset($archive_manager)) $data['archive'] = array(
