@@ -20,14 +20,16 @@
 require_once ('application/helpers/safe_helper.php');
 class Safe_os_wrapper
 {
-    public function execute($cmd, &$result = null, $escape = true, $superuser = false, &$return_var=null)
+    public function execute($cmd, &$result = null, $escape = true, $superuser = false, &$return_var=null, $log_error=true)
     {
         // PHP handle the os specific exec stuff
         // don't need to delegate to os specific class
         $return_var = 0;
         if ($superuser) $result = safe_sudo_exec($cmd, '', '', $return_var, $escape);
         else $result = safe_exec($cmd, '', '', $return_var, $escape);
-        if (0 !== $return_var) error_log('Exec <' . $cmd . '> failed=' . $return_var . ' output=' . print_r($result, true));
+        if (0 !== $return_var && $log_error){
+            error_log('Exec <' . $cmd . '> failed=' . $return_var . ' output=' . print_r($result, true));
+        }
         return ($return_var === 0);
     }
     public function service_ctl($service_name, $action, &$result = null, $process_name = null)
@@ -260,7 +262,7 @@ class Safe_os_wrapper
      * @param string $type = (UDP,TCP,ALL)
      * @param string $program_name
      */
-    public function valid_ip_port($ip, $port, $type_str = 'TCP', $program_name = '') {
+    public function valid_ip_port($ip, $port, $type_str = 'TCP', $program_name = '', &$user_prog='') {
         $ip     = strtoupper(trim($ip));
         $type_str = strtoupper(str_ireplace( array ('TLS','ALL'), array('TCP','TCPUDP'), $type_str));
         $param = '-lpn';
@@ -277,6 +279,8 @@ class Safe_os_wrapper
         $port_used_count = 0;
         $loop_cnt = 0;
         $max_loop = 5;
+        // Default is used
+        $port_used = true;
         do{
             // Default is used
             $port_used = true;
@@ -291,9 +295,9 @@ class Safe_os_wrapper
                             $port_used = false;
                         }
                     }
+                    $user_prog = substr(strrchr($matched_string, '/' ), 1 );
                     if($port_used == true && $program_name != '' && false !== ($tmp_pos=strpos($matched_string,$program_name)) ){
-                        $get_program_name = trim(substr($matched_string, $tmp_pos));
-                        if($get_program_name == $program_name){
+                        if($user_prog == $program_name || $user_prog== 'sh'){
                             $port_used = false;
                         }
                     }
